#!/usr/bin/python3

# bibtext to md converter
# (C) Massimo Girondi 2022 massimo@girondi.net
# CC BY-NC-SA 4.0


BIBFILE="massimo.bib"

from bibtexparser.bparser import BibTexParser
import bibtexparser
import re

with open(BIBFILE) as bibtex_file:
  bibtex_str = bibtex_file.read()

parser = BibTexParser(common_strings=False)
parser.ignore_nonstandard_types = False
parser.homogenise_fields = False
bib_database = bibtexparser.loads(bibtex_str, parser)

output = ""

entries = []
years = []
for e in bib_database.entries:
  print(e)
  # Remove curly brackers escapes
  ee = {k:re.sub(r"(\{)(.*)(\})", r"\2",v) for k,v in e.items()}
  author = ee['author']

  # Extract first and last names
  authors = author.split("and")
  authors = [a.split(',') for a in authors]

  # Change the order of name, surname and add and, at the last one
  # For sure there are better ways to do it...
  try:
    if all(len(a) == 2  for a in authors):
        author = [a[1].strip()+" "+a[0].strip() for a in authors]
        author = ", ".join(author[:-1])
        author += f", and {authors[-1][1]} {authors[-1][0]}"
        if len(authors) == 1:
          author = author[7:]
  except:
    print(f"Fall back to original author for e['title']")

  # Put me in bold
  author = re.sub(r"(Massimo Girondi|Girondi, Massimo)",r"**\1**", author)
  doi=f"[DOI](https://doi.org/{e['doi']})" if "doi" in e and not "doi" in e["doi"] else ""
  url=f"[URL]({e['url']})" if "url" in e else ""
  pdf=f"[PDF]({e['pdf']})" if "pdf" in e else ""
  diva=f"[DiVA]({e['diva']})" if "diva" in e else ""
  where = f"_{ee['booktitle']}_" if "booktitle" in e else ""
  where += (f" _{ee['school']}_") if "school" in ee else ""
  # Do not repeat year when conference is something like XXXX 20201
  when = f", {e['year']}. " if "year" in e and not where.endswith(e["year"]+"_") else ""
  note = f"  \n{ee['note']}" if "note" in e else ""
  title = f"**{ee['title']}**"
  entry=f"""* {title}  \n{author}.  \n{where}{when}{note}  \n{doi} {url} {pdf} {diva}"""

  entries.append(entry)
  # If date not givem put at top. TODO: won't last forever this trick :P
  years.append(ee['year'] if 'year' in ee else "3000")

# Order fron newest to oldest
entries = [e for _, e in sorted(zip(years,entries), reverse = True)]

with open("index.md", "w") as out:
  with open("header.md", "r") as header:
    out.write(header.read())
  out.write("\n".join(entries))
  with open("footer.md", "r") as header:
    out.write(header.read())

